@@ -91,6 +91,7 @@ enum { TINY_ICON_SIZE = 32, SMALL_ICON_SIZE = 48, MEDIUM_ICON_SIZE = 64,
 	SUPER_GIANT_ICON_SIZE = 256 };
 enum { SETTINGS_STATIONS_PAGE, SETTINGS_VISUALS_PAGE, SETTINGS_DISPLAY_PAGE,
 	SETTINGS_UNITS_PAGE, SETTINGS_UPDATE_PAGE, SETTINGS_SENSOR_PAGE, ABOUT_PAGE };
+enum {SHORT_CLICK, LONG_CLICK};
 /* station tab */
 enum { STATE_ENABLE_GPS	= 1U,
        STATE_SOURCE	= 2U
@@ -106,7 +107,9 @@ enum { STATE_ONE_ROW		= 1U,
        STATE_FONT		= 128U,
        STATE_FONT_COLOR		= 256U,
        STATE_BACKGROUND_COLOR	= 512U,
-       STATE_ICONSET		= 1024U
+       STATE_ICONSET		= 1024U,
+       STATE_LONG		= 2048U,
+       STATE_SHORT		= 4096U
 };
 /* display tab */
 enum { STATE_VISIBLE_ITEMS	= 1U,
@@ -228,6 +231,7 @@ typedef struct applet_config{
     gint	previos_days_to_show;
     gint	distance_units;
     gint	wind_units;
+    gint	clicking_type;
     gint	temperature_units;
     gint	pressure_units;
 #if defined(OS2008) || defined(DEBUGTEMP)
