@@ -593,8 +593,10 @@ read_config(AppletConfig *config){
     if(gerror || config->days_to_show <= 0
 	      || config->days_to_show > Max_count_weather_day){
 	config->days_to_show = 5;
-	if(gerror)
+	if(gerror){
 	    g_error_free(gerror);
+	    gerror = NULL;
+	}
     }
     config->previos_days_to_show = config->days_to_show;
 
@@ -604,8 +606,10 @@ read_config(AppletConfig *config){
 						    &gerror);
     if(gerror || config->distance_units > SEA_MILES){
 	config->distance_units = METERS;
-	if(gerror)
+	if(gerror){
 	    g_error_free(gerror);
+	    gerror = NULL;
+	}    
     }
     /* Get pressure units */
     config->pressure_units = gconf_client_get_int(gconf_client,                                                                                     
@@ -613,7 +617,10 @@ read_config(AppletConfig *config){
 						    &gerror);
     if(gerror || config->pressure_units < MB || config->pressure_units > MM){
 	config->pressure_units = MB;
-	g_error_free(gerror);
+	if(gerror){
+		g_error_free(gerror);
+		gerror = NULL;
+	}
     }
     /* Get wind units */
     config->wind_units = gconf_client_get_int(gconf_client,                                                                                     
@@ -621,9 +628,23 @@ read_config(AppletConfig *config){
 						&gerror);
     if(gerror || config->wind_units > MILES_H){
 	config->wind_units = METERS_S;
-	g_error_free(gerror);
+	if (gerror){
+		g_error_free(gerror);
+		gerror = NULL;
+	}
     }
-    /* Get switch time */
+    /* Get the  type of clicking default SHORT click */
+    config->clicking_type = gconf_client_get_int(gconf_client,
+                                                GCONF_KEY_CLICK_FOR_LAUNCH_POPUP,
+                                                   &gerror);
+    if(gerror || config->clicking_type > LONG_CLICK){
+        config->clicking_type = SHORT_CLICK;
+	if (gerror){
+        	g_error_free(gerror);
+        	gerror = NULL;
+	}
+    }
+   /* Get switch time */
     config->switch_time = gconf_client_get_int(gconf_client,
 				    GCONF_KEY_WEATHER_SWITCH_TIME,
 				    &gerror);
@@ -635,8 +656,10 @@ read_config(AppletConfig *config){
 		    config->switch_time != 50 &&
 		    config->switch_time != 60) ){
 	config->switch_time = 0;	/* Default value - Never */
-	if(gerror)
+	if(gerror){
 	    g_error_free(gerror);
+	    gerror = NULL;
+	}
     }
     else{
 	if(config->switch_time > 0){
@@ -656,8 +679,10 @@ read_config(AppletConfig *config){
 		    config->data_valid_interval != 4 &&
 		    config->data_valid_interval != 8) ){
 	config->data_valid_interval = 2 * 3600; /* Default value - 2 hours */
-	if(gerror)
+	if(gerror){
 	    g_error_free(gerror);
+	    gerror = NULL;
+	}
     }
     else
 	config->data_valid_interval *= 3600;
@@ -679,6 +704,10 @@ read_config(AppletConfig *config){
     }    
     gconf_client_clear_cache(gconf_client);
     g_object_unref(gconf_client);
+
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
     
     return 0;
 }
@@ -845,7 +874,11 @@ config_save(AppletConfig *config){
      /* Save Show Wind gust Button State */
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_SHOW_WIND_GUST,
-			config->show_wind_gust, NULL);
+ 			config->show_wind_gust, NULL);
+    /* Save Type of clicking for showing window popup */
+    gconf_client_set_int(gconf_client,
+        		GCONF_KEY_CLICK_FOR_LAUNCH_POPUP,
+			config->clicking_type, NULL);
      /* Show Station Name */
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_SHOW_STATION_NAME,
