@@ -133,7 +133,7 @@ create_about_dialog(void){
         			gtk_label_new(_("Thanks")));
 /* Translators tab */
     snprintf(tmp_buff, sizeof(tmp_buff) - 1, "%s",
-	    _("French - Nicolas Granziano\n"
+	    _("French - Nicolas Granziano, Philippe \n"
 	      "Russian - Pavel Fialko, Vlad Vasiliev,\n\t    Ed Bartosh\n"
 	      "Finnish - Marko Vertainen\n"
 	      "German - Claudius Henrichs\n"
