@@ -542,10 +542,10 @@ void draw_home_window(gint count_day){
 						    app->config->transparency,
 						    TRUE,
 						    &(app->config->background_color));
-
-	g_signal_connect(tmp_button->button, "button-release-event",
-			    G_CALLBACK(weather_window_popup),
-			    (is_na_day ? (GINT_TO_POINTER(-1)) : (GINT_TO_POINTER(i))));
+	if (app->config->clicking_type == SHORT_CLICK)
+	    g_signal_connect(tmp_button->button, "button-release-event",
+				G_CALLBACK(weather_window_popup),
+				(is_na_day ? (GINT_TO_POINTER(-1)) : (GINT_TO_POINTER(i))));
 	add_item2object(&(app->buttons), (void*)tmp_button);
 	if(!(app->config->separate && i == 1))
 	    tmp = g_slist_next(tmp);
@@ -884,6 +884,16 @@ void menu_init(void){
     START_FUNCTION;
 #endif
     app->contextmenu = gtk_menu_new();
+    gtk_menu_shell_append(GTK_MENU_SHELL(app->contextmenu),
+					menu_item = gtk_menu_item_new_with_label(_("Full forecast")));
+    g_signal_connect(G_OBJECT(menu_item), "activate",
+                    	    G_CALLBACK(weather_window_popup), (GINT_TO_POINTER(-1)));
+
+    gtk_menu_shell_append(GTK_MENU_SHELL(app->contextmenu),
+					menu_item = gtk_menu_item_new_with_label(_("Settings")));
+    g_signal_connect(G_OBJECT(menu_item), "activate",
+                    	    G_CALLBACK(weather_window_settings), NULL);
+
     valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(app->user_stations_list),
                                                   &iter);
     while(valid){
